==> huaweicloudsdkcae-3.1.45-py2.py3-none-any.whl: huaweicloudsdkcae/v1/model/metadata_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MetadataResponse:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'annotations': 'dict(str, str)',
        'created_at': 'datetime',
        'id': 'str',
        'jod_id': 'str',
        'name': 'str',
        'status': 'str',
        'type': 'str',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'annotations': 'annotations',
        'created_at': 'created_at',
        'id': 'id',
        'jod_id': 'jod_id',
        'name': 'name',
        'status': 'status',
        'type': 'type',
        'updated_at': 'updated_at'
    }

    def __init__(self, annotations=None, created_at=None, id=None, jod_id=None, name=None, status=None, type=None, updated_at=None):
        """MetadataResponse

        The model defined in huaweicloud sdk

        :param annotations: 属性信息。
        :type annotations: dict(str, str)
        :param created_at: 创建时间。
        :type created_at: datetime
        :param id: 组件id。
        :type id: str
        :param jod_id: 任务id。
        :type jod_id: str
        :param name: 名称。
        :type name: str
        :param status: 状态。
        :type status: str
        :param type: 组件类型。
        :type type: str
        :param updated_at: 更新时间。
        :type updated_at: datetime
        """
        
        

        self._annotations = None
        self._created_at = None
        self._id = None
        self._jod_id = None
        self._name = None
        self._status = None
        self._type = None
        self._updated_at = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if jod_id is not None:
            self.jod_id = jod_id
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def annotations(self):
        """Gets the annotations of this MetadataResponse.

        属性信息。

        :return: The annotations of this MetadataResponse.
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this MetadataResponse.

        属性信息。

        :param annotations: The annotations of this MetadataResponse.
        :type annotations: dict(str, str)
        """
        self._annotations = annotations

    @property
    def created_at(self):
        """Gets the created_at of this MetadataResponse.

        创建时间。

        :return: The created_at of this MetadataResponse.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this MetadataResponse.

        创建时间。

        :param created_at: The created_at of this MetadataResponse.
        :type created_at: datetime
        """
        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this MetadataResponse.

        组件id。

        :return: The id of this MetadataResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MetadataResponse.

        组件id。

        :param id: The id of this MetadataResponse.
        :type id: str
        """
        self._id = id

    @property
    def jod_id(self):
        """Gets the jod_id of this MetadataResponse.

        任务id。

        :return: The jod_id of this MetadataResponse.
        :rtype: str
        """
        return self._jod_id

    @jod_id.setter
    def jod_id(self, jod_id):
        """Sets the jod_id of this MetadataResponse.

        任务id。

        :param jod_id: The jod_id of this MetadataResponse.
        :type jod_id: str
        """
        self._jod_id = jod_id

    @property
    def name(self):
        """Gets the name of this MetadataResponse.

        名称。

        :return: The name of this MetadataResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MetadataResponse.

        名称。

        :param name: The name of this MetadataResponse.
        :type name: str
        """
        self._name = name

    @property
    def status(self):
        """Gets the status of this MetadataResponse.

        状态。

        :return: The status of this MetadataResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MetadataResponse.

        状态。

        :param status: The status of this MetadataResponse.
        :type status: str
        """
        self._status = status

    @property
    def type(self):
        """Gets the type of this MetadataResponse.

        组件类型。

        :return: The type of this MetadataResponse.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MetadataResponse.

        组件类型。

        :param type: The type of this MetadataResponse.
        :type type: str
        """
        self._type = type

    @property
    def updated_at(self):
        """Gets the updated_at of this MetadataResponse.

        更新时间。

        :return: The updated_at of this MetadataResponse.
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this MetadataResponse.

        更新时间。

        :param updated_at: The updated_at of this MetadataResponse.
        :type updated_at: datetime
        """
        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetadataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcae-3.1.58-py2.py3-none-any.whl: huaweicloudsdkcae/v1/model/metadata_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MetadataResponse:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'name': 'str',
        'annotations': 'dict(str, str)',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'annotations': 'annotations',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, name=None, annotations=None, created_at=None, updated_at=None):
        """MetadataResponse

        The model defined in huaweicloud sdk

        :param id: 组件ID。
        :type id: str
        :param name: 组件名称。
        :type name: str
        :param annotations: 组件附加属性。 - log_group_id：LTS日志组的ID。 - log_stream_id：LTS日志流的ID。 - version：组件版本。
        :type annotations: dict(str, str)
        :param created_at: 创建时间。
        :type created_at: datetime
        :param updated_at: 更新时间。
        :type updated_at: datetime
        """
        
        

        self._id = None
        self._name = None
        self._annotations = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if annotations is not None:
            self.annotations = annotations
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this MetadataResponse.

        组件ID。

        :return: The id of this MetadataResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MetadataResponse.

        组件ID。

        :param id: The id of this MetadataResponse.
        :type id: str
        """
        self._id = id

    @property
    def name(self):
        """Gets the name of this MetadataResponse.

        组件名称。

        :return: The name of this MetadataResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MetadataResponse.

        组件名称。

        :param name: The name of this MetadataResponse.
        :type name: str
        """
        self._name = name

    @property
    def annotations(self):
        """Gets the annotations of this MetadataResponse.

        组件附加属性。 - log_group_id：LTS日志组的ID。 - log_stream_id：LTS日志流的ID。 - version：组件版本。

        :return: The annotations of this MetadataResponse.
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this MetadataResponse.

        组件附加属性。 - log_group_id：LTS日志组的ID。 - log_stream_id：LTS日志流的ID。 - version：组件版本。

        :param annotations: The annotations of this MetadataResponse.
        :type annotations: dict(str, str)
        """
        self._annotations = annotations

    @property
    def created_at(self):
        """Gets the created_at of this MetadataResponse.

        创建时间。

        :return: The created_at of this MetadataResponse.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this MetadataResponse.

        创建时间。

        :param created_at: The created_at of this MetadataResponse.
        :type created_at: datetime
        """
        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this MetadataResponse.

        更新时间。

        :return: The updated_at of this MetadataResponse.
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this MetadataResponse.

        更新时间。

        :param updated_at: The updated_at of this MetadataResponse.
        :type updated_at: datetime
        """
        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetadataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
